@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c 18110 2017-05-03 01:29:16Z pwessel $
+ *	$Id: grdcontour.c 19521 2017-12-27 22:38:24Z pwessel $
  *
- *	Copyright (c) 1991-2017 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -435,7 +435,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 								A[0] = string[0];	Ctrl->T.txt[0] = strdup (A);
 								A[0] = string[1];	Ctrl->T.txt[1] = strdup (A);
 							}
-							else if (strchr (&(opt->arg[j]), ',') && (n = sscanf (&(opt->arg[j]), "%[^,],%s", txt_a, txt_b)) == 2) {	/* Found :<labellow>,<labelhigh> */
+							else if (strchr (string, ',') && (n = sscanf (string, "%[^,],%s", txt_a, txt_b)) == 2) {	/* Found :<labellow>,<labelhigh> */
 								Ctrl->T.txt[0] = strdup (txt_a);
 								Ctrl->T.txt[1] = strdup (txt_b);
 							}
@@ -896,7 +896,8 @@ int GMT_grdcontour (void *V_API, int mode, void *args) {
 
 	/* Determine what wesn to pass to map_setup */
 
-	if (!GMT->common.R.active[RSET]) gmt_M_memcpy (GMT->common.R.wesn, G->header->wesn, 4, double);	/* -R was not set so we use the grid domain */
+	if (!GMT->common.R.active[RSET])	/* -R was not set so we use the grid domain */
+		gmt_set_R_from_grd (GMT, G->header);
 
 	if (need_proj && gmt_map_setup (GMT, GMT->common.R.wesn)) Return (GMT_PROJECTION_ERROR);
 
@@ -1092,6 +1093,10 @@ int GMT_grdcontour (void *V_API, int mode, void *args) {
 		if (!GMT->current.map.z_periodic && min < G->header->z_min) min += Ctrl->C.interval;
 		max = ceil (G->header->z_max / Ctrl->C.interval) * Ctrl->C.interval;
 		if (max > G->header->z_max) max -= Ctrl->C.interval;
+		if (Ctrl->A.interval > Ctrl->C.interval && fabs ((Ctrl->A.interval/Ctrl->C.interval) - irint (Ctrl->A.interval/Ctrl->C.interval)) > GMT_CONV4_LIMIT)
+			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Annotation interval is not a multiple of contour interval - no annotated contours will be drawn.\n");
+		else if (Ctrl->contour.annot && Ctrl->A.interval < Ctrl->C.interval)
+			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Annotation interval < contour interval - some/all annotated contours will not be drawn.\n");
 		for (c = irint (min/Ctrl->C.interval), n_contours = 0; c <= irint (max/Ctrl->C.interval); c++, n_contours++) {
 			if (n_contours == n_alloc) {
 				n_tmp = n_alloc;
