@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c 18282 2017-05-30 01:57:05Z pwessel $
+ *	$Id: grdvector.c 19521 2017-12-27 22:38:24Z pwessel $
  *
- *	Copyright (c) 1991-2017 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -371,7 +371,8 @@ int GMT_grdvector (void *V_API, int mode, void *args) {
 
 	/* Determine what wesn to pass to map_setup */
 
-	if (!GMT->common.R.active[RSET]) gmt_M_memcpy (GMT->common.R.wesn, Grid[0]->header->wesn, 4, double);
+	if (!GMT->common.R.active[RSET])	/* -R was not set so we use the grid domain */
+		gmt_set_R_from_grd (GMT, Grid[0]->header);
 
 	if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, GMT->common.R.wesn), "")) Return (GMT_PROJECTION_ERROR);
 
